.. _moduleref:

.. index::
   single: Function reference
   single: Class reference

.. module:: mumott

:program:`mumott`
*****************

.. toctree::
   :maxdepth: 2
   :caption: Contents

   core
   data_handling
   output_handling
   optimization